@@ -26,7 +26,7 @@
 
 G_BEGIN_DECLS
 
-#define GNOME_DB_BASIC_FORM_TYPE          (gnome_db_basic_form_get_type())
+#define GNOME_DB_TYPE_BASIC_FORM          (gnome_db_basic_form_get_type())
 #define GNOME_DB_BASIC_FORM(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_basic_form_get_type(), GnomeDbBasicForm)
 #define GNOME_DB_BASIC_FORM_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_basic_form_get_type (), GnomeDbBasicFormClass)
 #define IS_GNOME_DB_BASIC_FORM(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_basic_form_get_type ())
@@ -56,7 +56,7 @@ struct _GnomeDbBasicFormClass
 /* 
  * Generic widget's methods 
 */
-guint           gnome_db_basic_form_get_type                 (void);
+GType           gnome_db_basic_form_get_type                 (void);
 GtkWidget      *gnome_db_basic_form_new                      (GnomeDbDict *dict, GnomeDbDataSet *data_set);
 GtkWidget      *gnome_db_basic_form_new_in_layout            (GnomeDbDict *dict, GnomeDbDataSet *data_set, 
 							      GtkWidget *layout, GHashTable *box_widgets);
