@@ -23,6 +23,9 @@
 #include "marshal.h"
 #include <libxml/parser.h>
 #include <libxml/tree.h>
+#include <libxml/xpath.h>
+#include <libxml/xpathInternals.h>
+
 #include "gnome-db-base.h"
 #include "gnome-db-server.h"
 #include "gnome-db-database.h"
@@ -34,6 +37,12 @@
 #include "graph/gnome-db-graph.h"
 #include "graph/gnome-db-graph-query.h"
 #include "gnome-db-custom-layout.h"
+#include "utility.h"
+
+#if defined(LIBXML_XPATH_ENABLED) && defined(LIBXML_SAX1_ENABLED) && \
+    defined(LIBXML_OUTPUT_ENABLED)
+#define XML_ID_TEST 
+#endif
 
 /* 
  * Main static functions 
@@ -317,7 +326,7 @@ gnome_db_dict_new ()
 	GObject   *obj;
 	GnomeDbDict *dict;
 
-	obj = g_object_new (GNOME_DB_DICT_TYPE, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_DICT, NULL);
 	dict = GNOME_DB_DICT (obj);
 
 	/* Server and database objects creation */
@@ -480,6 +489,110 @@ gnome_db_dict_get_property (GObject              *object,
 	}
 }
 
+#ifdef XML_ID_TEST
+static void xml_id_update_tree_recurs (xmlDocPtr doc, xmlNodePtr node, GHashTable *keys);
+
+/*
+ * Goes through all the @doc tree and replaces ID and IDREF with the new naming scheme.
+ */
+static void
+xml_id_update_tree (xmlDocPtr doc)
+{
+	GHashTable *keys;
+	xmlNodePtr node;
+
+	g_assert (node);
+	keys = g_hash_table_new_full (g_str_hash, g_str_equal, xmlFree, g_free);
+
+	node = xmlDocGetRootElement (doc);
+	xml_id_update_tree_recurs (doc, node, keys);
+	g_hash_table_destroy (keys);
+}
+
+static void
+xml_id_update_tree_recurs (xmlDocPtr doc, xmlNodePtr node, GHashTable *keys)
+{
+	static gchar* upd_nodes[] = {"GNOME_DB_DATATYPE",
+				     "GNOME_DB_FUNCTION",
+				     "GNOME_DB_AGGREGATE",
+				     "GNOME_DB_TABLE",
+				     "GNOME_DB_FIELD"};
+	static gchar* upd_prefix[] = {"DT",
+				      "PR",
+				      "AG",
+				      "TV",
+				      "FI"};
+	gint i;
+	xmlAttrPtr attr;
+	xmlNodePtr child;
+
+	/* update this node'id if necessary */
+	for (i = 0; i < 5; i++) {
+		if (!strcmp (node->name, upd_nodes [i])) {
+			gchar *oid, *id, *name;
+			
+			name = xmlGetProp (node, "name");
+			oid = xmlGetProp (node, "id");
+			g_assert (name && oid);
+
+			switch (i) {
+			default:
+				id = utility_build_encoded_id (upd_prefix [i], name);
+				break;
+			case 4: {
+				/* GNOME_DB_FIELD has a composed ID */
+				gchar *tableid, *tmp;
+				xmlNodePtr parent = node->parent;
+
+				g_assert (parent);
+				tableid = xmlGetProp (parent, "id");
+				tmp = utility_build_encoded_id (upd_prefix [i], name);
+				id = g_strconcat (tableid, ":", tmp, NULL);
+				g_free (tmp);
+				xmlFree (tableid);
+				break;
+			}
+			case 1:
+			case 2: 
+				/* GNOME_DB_FUNCTION and GNOME_DB_AGGREGATE encode their DBMS id */
+				id = utility_build_encoded_id (upd_prefix [i], oid+2);
+				break;
+			}
+
+			xmlSetProp (node, "id", id);
+			/*g_print ("UPDATE ID %s: \tname=%s, oldid=%s, id=%s\n", upd_nodes [i], name, oid, id);*/
+
+			g_hash_table_insert (keys, oid, id); /* don't free oid and id as they will be when hash is destroyed */
+			xmlFree (name);
+			break;
+		}
+	}
+
+	/* update any reference in this node */
+	attr = node->properties;
+	while (attr) {
+		gchar *oid, *id;
+		
+		oid = xmlGetProp (node, attr->name);
+		g_assert (oid);
+		id = g_hash_table_lookup (keys, oid);
+		if (id) {
+			xmlSetProp (node, attr->name, id);
+			/*g_print ("replace ref %s: \tattr=%s, oldref=%s, newref=%s\n", attr->name, node->name, oid, id);*/
+		}
+		xmlFree (oid);
+		attr = attr->next;
+	}
+
+	/* update children */
+	child = node->children;
+	while (child) {
+		xml_id_update_tree_recurs (doc, child, keys);
+		child = child->next;
+	}
+}
+
+#endif
 
 static void xml_validity_error_func (void *ctx, const char *msg, ...);
 
@@ -594,6 +707,55 @@ gnome_db_dict_load_xml_file (GnomeDbDict *dict, const gchar *xmlfile, GError **e
 			     xmlfile);
 		return FALSE;
 	}
+
+#ifdef XML_ID_TEST
+	{
+		/* test if we need to update the XML ID of the nodes in the tree */
+		xmlXPathContextPtr xpathCtx; 
+
+		xpathCtx = xmlXPathNewContext(doc);
+		if (xpathCtx) {
+			xmlXPathObjectPtr xpathObj; 
+
+			xpathObj = xmlXPathEvalExpression("//GNOME_DB_DATATYPE", xpathCtx);
+			if (xpathObj) {
+				xmlNodeSetPtr nodes;
+				xmlNodePtr node = NULL;
+
+				nodes = xpathObj->nodesetval;
+				if (nodes && (nodes->nodeNr > 0))
+					node = nodes->nodeTab [0];
+					
+				if (node) {
+					gchar *id, *name;
+
+					id = xmlGetProp (node, "id");
+					name = xmlGetProp (node, "name");
+					
+					if (id && name) {
+						gchar *tmp;
+
+						tmp = utility_build_encoded_id ("DT", name);
+						if (strcmp (tmp, id)) {
+							g_print ("Updating XML IDs and IDREFs of this dictionary...\n");
+							xml_id_update_tree (doc);
+						}
+						g_free (tmp);
+					}
+					
+					if (id)
+						xmlFree (id);
+					if (name)
+						xmlFree (name);
+				}
+
+				xmlXPathFreeObject (xpathObj);
+			}
+			xmlXPathFreeContext(xpathCtx);
+		}
+	}
+#endif
+
 	if (!gnome_db_xml_storage_load_from_xml (GNOME_DB_XML_STORAGE (dict->priv->srv), subnode, error))
 		return FALSE;
 	
