@@ -123,7 +123,7 @@ enum
 	PROP_ACTIONS_VISIBLE
 };
 
-guint
+GType
 gnome_db_form_get_type (void)
 {
 	static GType type = 0;
@@ -148,7 +148,7 @@ gnome_db_form_get_type (void)
                 };
 		
 		type = g_type_register_static (GTK_TYPE_VBOX, "GnomeDbForm", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_DATA_WIDGET_TYPE, &work_widget_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_DATA_WIDGET, &work_widget_info);
 	}
 
 	return type;
@@ -216,7 +216,7 @@ gnome_db_form_new (void)
 {
 	GObject *obj;
 	
-	obj = g_object_new (GNOME_DB_FORM_TYPE, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_FORM, NULL);
 	
 	return GTK_WIDGET (obj);	
 }
@@ -300,7 +300,7 @@ gnome_db_form_new_in_layout (GnomeDbQuery *query, GnomeDbTarget *modified, GtkWi
 		g_return_val_if_fail (gnome_db_entity_is_writable (gnome_db_target_get_represented_entity (modified)), NULL);
 	}
 	
-	obj = g_object_new (GNOME_DB_FORM_TYPE, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_FORM, NULL);
 	form = GNOME_DB_FORM (obj);
 
 	rs = GNOME_DB_RESULT_SET (gnome_db_result_set_new (query, modified));
