@@ -130,7 +130,7 @@ GQuark gnome_db_model_wrapper_error_quark (void)
 }
 
 
-guint
+GType
 gnome_db_model_wrapper_get_type (void)
 {
 	static GType type = 0;
@@ -166,10 +166,10 @@ gnome_db_model_wrapper_get_type (void)
 			NULL
 		};
 		
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbModelWrapper", &info, 0);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbModelWrapper", &info, 0);
 		g_type_add_interface_static (type, GDA_TYPE_DATA_MODEL, &gda_model_info);
-		g_type_add_interface_static (type, GNOME_DB_ENTITY_TYPE, &entity_info);
-		g_type_add_interface_static (type, GNOME_DB_DATA_MODEL_TYPE, &model_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_ENTITY, &entity_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_DATA_MODEL, &model_info);
 	}
 	return type;
 }
@@ -281,7 +281,7 @@ gnome_db_model_wrapper_new (GnomeDbDict *dict, GdaDataModel *model)
 	g_return_val_if_fail (!dict || IS_GNOME_DB_DICT (dict), NULL);
 	g_return_val_if_fail (model && GDA_IS_DATA_MODEL (model), NULL);
 
-	obj = g_object_new (GNOME_DB_MODEL_WRAPPER_TYPE, "dict", ASSERT_DICT (dict), NULL);
+	obj = g_object_new (GNOME_DB_TYPE_MODEL_WRAPPER, "dict", ASSERT_DICT (dict), NULL);
 	wrapper = GNOME_DB_MODEL_WRAPPER (obj);
 
 	wrapper->priv->model = model;
@@ -490,7 +490,7 @@ gnome_db_model_wrapper_model_copy (GnomeDbDataModel *iface, GHashTable *replacem
 	orig = GNOME_DB_MODEL_WRAPPER (iface);
 	g_return_val_if_fail (orig->priv, NULL);
 
-	obj = g_object_new (GNOME_DB_MODEL_WRAPPER_TYPE, "dict", gnome_db_base_get_dict (GNOME_DB_BASE (orig)), NULL);
+	obj = g_object_new (GNOME_DB_TYPE_MODEL_WRAPPER, "dict", gnome_db_base_get_dict (GNOME_DB_BASE (orig)), NULL);
 	wrapper = GNOME_DB_MODEL_WRAPPER (obj);
 
 	wrapper->priv->model = orig->priv->model;
