@@ -84,8 +84,6 @@ static gboolean    gnome_db_qf_value_is_equal       (GnomeDbQfield *qfield1, Gno
 static void nullified_object_cb (GObject *obj, GnomeDbQfValue *field);
 
 static GSList   *gnome_db_qf_value_get_params (GnomeDbQfield *qfield);
-static gboolean  gnome_db_qf_value_restrict_with_field (GnomeDbQfValue *field, GnomeDbQfield *provider, GError **error);
-static gboolean  gnome_db_qf_value_restrict_with_field_xml (GnomeDbQfValue *field, const gchar *prov_xml_id, GError **error);
 
 static gboolean gnome_db_qf_value_render_find_value (GnomeDbQfValue *field, GnomeDbDataSet *context,
 					       const GdaValue **value_found, GnomeDbParameter **param_source);
@@ -121,15 +119,15 @@ enum
 struct _GnomeDbQfValuePrivate
 {
 	GnomeDbQuery          *query;
-	GdaValueType      gda_type;
+	GdaValueType           gda_type;
 	GnomeDbServerDataType *srv_type;
-	GdaValue         *value;        /* MUST either be NULL, or of type GDA_VALUE_NULL or 'type' */
-	GdaValue         *default_value;/* CAN either be NULL, or of any type */
-	gboolean          is_parameter;
-	gboolean          is_null_allowed;
+	GdaValue              *value;        /* MUST either be NULL, or of type GDA_VALUE_NULL or 'type' */
+	GdaValue              *default_value;/* CAN either be NULL, or of any type */
+	gboolean               is_parameter;
+	gboolean               is_null_allowed;
 	GnomeDbRefBase        *value_prov_ref; /* to a GnomeDbQfield of another query */
 
-	gchar            *plugin;       /* specific plugin to be used */
+	gchar                 *plugin;       /* specific plugin to be used */
 };
 
 
@@ -143,7 +141,7 @@ GQuark gnome_db_qf_value_error_quark (void)
 }
 
 
-guint
+GType
 gnome_db_qf_value_get_type (void)
 {
 	static GType type = 0;
@@ -186,11 +184,11 @@ gnome_db_qf_value_get_type (void)
 		};
 		
 		
-		type = g_type_register_static (GNOME_DB_QFIELD_TYPE, "GnomeDbQfValue", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_XML_STORAGE_TYPE, &xml_storage_info);
-		g_type_add_interface_static (type, GNOME_DB_FIELD_TYPE, &field_info);
-		g_type_add_interface_static (type, GNOME_DB_RENDERER_TYPE, &renderer_info);
-		g_type_add_interface_static (type, GNOME_DB_REFERER_TYPE, &referer_info);
+		type = g_type_register_static (GNOME_DB_TYPE_QFIELD, "GnomeDbQfValue", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_XML_STORAGE, &xml_storage_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_FIELD, &field_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_RENDERER, &renderer_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_REFERER, &referer_info);
 	}
 	return type;
 }
@@ -311,7 +309,7 @@ gnome_db_qf_value_new (GnomeDbQuery *query, GnomeDbServerDataType *type)
 	g_return_val_if_fail (type && IS_GNOME_DB_SERVER_DATA_TYPE (type), NULL);
 	dict = gnome_db_base_get_dict (GNOME_DB_BASE (query));
 
-	obj = g_object_new (GNOME_DB_QF_VALUE_TYPE, "dict", dict, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_QF_VALUE, "dict", dict, NULL);
 	gnome_db_qf_value = GNOME_DB_QF_VALUE (obj);
 	g_object_get (G_OBJECT (query), "field_serial", &id, NULL);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_qf_value), id);
@@ -826,7 +824,7 @@ gnome_db_qf_value_is_value_null (GnomeDbQfValue *field, GnomeDbDataSet *context)
  *
  * Returns: TRUE if no error occurred
  */
-static gboolean
+gboolean
 gnome_db_qf_value_restrict_with_field (GnomeDbQfValue *field, GnomeDbQfield *provider, GError **error)
 {
 	g_return_val_if_fail (field && IS_GNOME_DB_QF_VALUE (field), FALSE);
@@ -878,7 +876,7 @@ gnome_db_qf_value_restrict_with_field (GnomeDbQfValue *field, GnomeDbQfield *pro
 		}
 		
 		field->priv->value_prov_ref = GNOME_DB_REF_BASE (gnome_db_ref_base_new (gnome_db_base_get_dict (GNOME_DB_BASE (field))));
-		gnome_db_ref_base_set_ref_object_type (field->priv->value_prov_ref, GNOME_DB_BASE (provider), GNOME_DB_FIELD_TYPE);
+		gnome_db_ref_base_set_ref_object_type (field->priv->value_prov_ref, GNOME_DB_BASE (provider), GNOME_DB_TYPE_FIELD);
 	}
 	
 	return TRUE;
@@ -894,7 +892,7 @@ gnome_db_qf_value_restrict_with_field (GnomeDbQfValue *field, GnomeDbQfield *pro
  *
  * Returns: TRUE if no error occurred
  */
-static gboolean 
+gboolean 
 gnome_db_qf_value_restrict_with_field_xml (GnomeDbQfValue *field, const gchar *prov_xml_id, GError **error)
 {
 	g_return_val_if_fail (field && IS_GNOME_DB_QF_VALUE (field), FALSE);
@@ -908,7 +906,7 @@ gnome_db_qf_value_restrict_with_field_xml (GnomeDbQfValue *field, const gchar *p
 	if (prov_xml_id) {
 		/* No test possible, really */
 		field->priv->value_prov_ref = GNOME_DB_REF_BASE (gnome_db_ref_base_new (gnome_db_base_get_dict (GNOME_DB_BASE (field))));
-		gnome_db_ref_base_set_ref_name (field->priv->value_prov_ref, GNOME_DB_FIELD_TYPE, REFERENCE_BY_XML_ID,
+		gnome_db_ref_base_set_ref_name (field->priv->value_prov_ref, GNOME_DB_TYPE_FIELD, REFERENCE_BY_XML_ID,
 						prov_xml_id);
 	}
 
