@@ -66,7 +66,7 @@ gnome_db_entry_boolean_get_type (void)
 			(GInstanceInitFunc) gnome_db_entry_boolean_init
 		};
 		
-		type = g_type_register_static (GNOME_DB_ENTRY_WRAPPER_TYPE, "GnomeDbEntryBoolean", &info, 0);
+		type = g_type_register_static (GNOME_DB_TYPE_ENTRY_WRAPPER, "GnomeDbEntryBoolean", &info, 0);
 	}
 	return type;
 }
@@ -115,7 +115,7 @@ gnome_db_entry_boolean_new (GnomeDbDataHandler *dh, GdaValueType type)
 	g_return_val_if_fail (type != GDA_VALUE_TYPE_UNKNOWN, NULL);
 	g_return_val_if_fail (gnome_db_data_handler_accepts_gda_type (dh, type), NULL);
 
-	obj = g_object_new (GNOME_DB_ENTRY_BOOLEAN_TYPE, "handler", dh, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_ENTRY_BOOLEAN, "handler", dh, NULL);
 	mgbool = GNOME_DB_ENTRY_BOOLEAN (obj);
 	gnome_db_data_entry_set_value_type (GNOME_DB_DATA_ENTRY (mgbool), type);
 
